@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -46,12 +46,13 @@
 #include "a2functional.h"
 #include "bittorrent_helper.h"
 #include "bitfield.h"
+#include "wallclock.h"
 
 namespace aria2 {
 
 DHTBucket::DHTBucket(size_t prefixLength,
-		     const unsigned char* max, const unsigned char* min,
-		     const SharedHandle<DHTNode>& localNode):
+                     const unsigned char* max, const unsigned char* min,
+                     const SharedHandle<DHTNode>& localNode):
   _prefixLength(prefixLength),
   _localNode(localNode),
   _logger(LogFactory::getInstance())
@@ -74,10 +75,10 @@ DHTBucket::~DHTBucket() {}
 void DHTBucket::getRandomNodeID(unsigned char* nodeID) const
 {
   if(_prefixLength == 0) {
-    bittorrent::generateRandomKey(nodeID);
+    util::generateRandomKey(nodeID);
   } else {
     size_t lastByteIndex = (_prefixLength-1)/8;
-    bittorrent::generateRandomKey(nodeID);
+    util::generateRandomKey(nodeID);
     memcpy(nodeID, _min, lastByteIndex+1);
   }
 }
@@ -94,31 +95,32 @@ bool DHTBucket::isInRange(const unsigned char* nodeID) const
 
 // Returns true if nodeID is in [min, max] (inclusive).
 bool DHTBucket::isInRange(const unsigned char* nodeID,
-			  const unsigned char* max,
-			  const unsigned char* min) const
+                          const unsigned char* max,
+                          const unsigned char* min) const
 {
   return
     !std::lexicographical_compare(&nodeID[0], &nodeID[DHT_ID_LENGTH],
-				  &min[0], &min[DHT_ID_LENGTH]) &&
+                                  &min[0], &min[DHT_ID_LENGTH]) &&
     !std::lexicographical_compare(&max[0], &max[DHT_ID_LENGTH],
-				  &nodeID[0], &nodeID[DHT_ID_LENGTH]);
+                                  &nodeID[0], &nodeID[DHT_ID_LENGTH]);
 }
 
 bool DHTBucket::addNode(const SharedHandle<DHTNode>& node)
 {
   notifyUpdate();
-  std::deque<SharedHandle<DHTNode> >::iterator itr = std::find(_nodes.begin(), _nodes.end(), node);
+  std::deque<SharedHandle<DHTNode> >::iterator itr =
+    std::find(_nodes.begin(), _nodes.end(), node);
   if(itr == _nodes.end()) {
     if(_nodes.size() < K) {
       _nodes.push_back(node);
       return true;
     } else {
       if(_nodes.front()->isBad()) {
-	_nodes.erase(_nodes.begin());
-	_nodes.push_back(node);
-	return true;
+        _nodes.erase(_nodes.begin());
+        _nodes.push_back(node);
+        return true;
       } else {
-	return false;
+        return false;
       }
     }
   } else {
@@ -140,7 +142,8 @@ void DHTBucket::cacheNode(const SharedHandle<DHTNode>& node)
 void DHTBucket::dropNode(const SharedHandle<DHTNode>& node)
 {
   if(_cachedNodes.size()) {
-    std::deque<SharedHandle<DHTNode> >::iterator itr = find(_nodes.begin(), _nodes.end(), node);
+    std::deque<SharedHandle<DHTNode> >::iterator itr =
+      find(_nodes.begin(), _nodes.end(), node);
     if(itr != _nodes.end()) {
       _nodes.erase(itr);
       _nodes.push_back(_cachedNodes.front());
@@ -188,11 +191,11 @@ SharedHandle<DHTBucket> DHTBucket::split()
 
   ++_prefixLength;
   SharedHandle<DHTBucket> rBucket(new DHTBucket(_prefixLength,
-						rMax, rMin, _localNode));
+                                                rMax, rMin, _localNode));
 
   std::deque<SharedHandle<DHTNode> > lNodes;
-  for(std::deque<SharedHandle<DHTNode> >::iterator i = _nodes.begin();
-      i != _nodes.end(); ++i) {
+  for(std::deque<SharedHandle<DHTNode> >::iterator i = _nodes.begin(),
+        eoi = _nodes.end(); i != eoi; ++i) {
     if(rBucket->isInRange(*i)) {
       assert(rBucket->addNode(*i));
     } else {
@@ -201,23 +204,25 @@ SharedHandle<DHTBucket> DHTBucket::split()
   }
   _nodes = lNodes;
   // TODO create toString() and use it.
-  _logger->debug("New bucket. prefixLength=%u, Range:%s-%s",
-		 static_cast<unsigned int>(rBucket->getPrefixLength()),
- 		 util::toHex(rBucket->getMinID(), DHT_ID_LENGTH).c_str(),
- 		 util::toHex(rBucket->getMaxID(), DHT_ID_LENGTH).c_str());
-  _logger->debug("Existing bucket. prefixLength=%u, Range:%s-%s",
-		 static_cast<unsigned int>(_prefixLength),
-		 util::toHex(getMinID(), DHT_ID_LENGTH).c_str(),
-		 util::toHex(getMaxID(), DHT_ID_LENGTH).c_str());
-
+  if(_logger->debug()) {
+    _logger->debug("New bucket. prefixLength=%u, Range:%s-%s",
+                   static_cast<unsigned int>(rBucket->getPrefixLength()),
+                   util::toHex(rBucket->getMinID(), DHT_ID_LENGTH).c_str(),
+                   util::toHex(rBucket->getMaxID(), DHT_ID_LENGTH).c_str());
+    _logger->debug("Existing bucket. prefixLength=%u, Range:%s-%s",
+                   static_cast<unsigned int>(_prefixLength),
+                   util::toHex(getMinID(), DHT_ID_LENGTH).c_str(),
+                   util::toHex(getMaxID(), DHT_ID_LENGTH).c_str());
+  }
   return rBucket;
 }
 
-void DHTBucket::getGoodNodes(std::deque<SharedHandle<DHTNode> >& goodNodes) const
+void DHTBucket::getGoodNodes
+(std::vector<SharedHandle<DHTNode> >& goodNodes) const
 {
-  goodNodes = _nodes;
+  goodNodes.insert(goodNodes.end(), _nodes.begin(), _nodes.end());  
   goodNodes.erase(std::remove_if(goodNodes.begin(), goodNodes.end(),
-				 mem_fun_sh(&DHTNode::isBad)), goodNodes.end());
+                                 mem_fun_sh(&DHTNode::isBad)), goodNodes.end());
 }
 
 SharedHandle<DHTNode> DHTBucket::getNode(const unsigned char* nodeID, const std::string& ipaddr, uint16_t port) const
@@ -242,12 +247,13 @@ bool DHTBucket::operator==(const DHTBucket& bucket) const
 
 bool DHTBucket::needsRefresh() const
 {
-  return _nodes.size() < K || _lastUpdated.elapsed(DHT_BUCKET_REFRESH_INTERVAL);
+  return _nodes.size() < K ||
+    _lastUpdated.difference(global::wallclock) >= DHT_BUCKET_REFRESH_INTERVAL;
 }
 
 void DHTBucket::notifyUpdate()
 {
-  _lastUpdated.reset();
+  _lastUpdated = global::wallclock;
 }
 
 class FindQuestionableNode {
