@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,11 +36,14 @@
 #define _D_DHT_BUCKET_H_
 
 #include "common.h"
+
+#include <string>
+#include <deque>
+#include <vector>
+
 #include "SharedHandle.h"
 #include "DHTConstants.h"
 #include "TimeA2.h"
-#include <string>
-#include <deque>
 
 namespace aria2 {
 
@@ -70,13 +73,13 @@ private:
   Logger* _logger;
 
   bool isInRange(const unsigned char* nodeID,
-		 const unsigned char* max, const unsigned char* min) const;
+                 const unsigned char* max, const unsigned char* min) const;
 public:
   DHTBucket(const SharedHandle<DHTNode>& localNode);
 
   DHTBucket(size_t prefixLength,
-	    const unsigned char* max, const unsigned char* min,
-	    const SharedHandle<DHTNode>& localNode);
+            const unsigned char* max, const unsigned char* min,
+            const SharedHandle<DHTNode>& localNode);
 
   ~DHTBucket();
 
@@ -123,7 +126,7 @@ public:
     return _nodes;
   }
 
-  void getGoodNodes(std::deque<SharedHandle<DHTNode> >& nodes) const;
+  void getGoodNodes(std::vector<SharedHandle<DHTNode> >& nodes) const;
 
   void dropNode(const SharedHandle<DHTNode>& node);
 
