@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,12 +38,13 @@
 #include "DHTMessageCallback.h"
 #include "DHTConstants.h"
 #include "util.h"
+#include "wallclock.h"
 
 namespace aria2 {
 
 DHTMessageTrackerEntry::DHTMessageTrackerEntry(const SharedHandle<DHTMessage>& sentMessage,
-					       time_t timeout,
-					       const SharedHandle<DHTMessageCallback>& callback):
+                                               time_t timeout,
+                                               const SharedHandle<DHTMessageCallback>& callback):
   _targetNode(sentMessage->getRemoteNode()),
   _transactionID(sentMessage->getTransactionID()),
   _messageType(sentMessage->getMessageType()),
@@ -53,7 +54,7 @@ DHTMessageTrackerEntry::DHTMessageTrackerEntry(const SharedHandle<DHTMessage>& s
 
 bool DHTMessageTrackerEntry::isTimeout() const
 {
-  return _dispatchedTime.elapsed(_timeout);
+  return _dispatchedTime.difference(global::wallclock) >= _timeout;
 }
 
 void DHTMessageTrackerEntry::extendTimeout()
