@@ -48,7 +48,9 @@
 
 namespace aria2 {
 
-FileAllocationCommand::FileAllocationCommand(int cuid, RequestGroup* requestGroup, DownloadEngine* e, const FileAllocationEntryHandle& fileAllocationEntry):
+FileAllocationCommand::FileAllocationCommand
+(int cuid, RequestGroup* requestGroup, DownloadEngine* e,
+ const SharedHandle<FileAllocationEntry>& fileAllocationEntry):
   RealtimeCommand(cuid, requestGroup, e),
   _fileAllocationEntry(fileAllocationEntry) {}
 
@@ -68,7 +70,7 @@ bool FileAllocationCommand::executeInternal()
     }
     _e->_fileAllocationMan->dropPickedEntry();
     
-    std::deque<Command*> commands;
+    std::vector<Command*> commands;
     try {
       _fileAllocationEntry->prepareForNextAction(commands, _e);
     } catch(RecoverableException& e) {
