@@ -33,9 +33,6 @@
  */
 /* copyright --> */
 #include "HttpResponse.h"
-
-#include <deque>
-
 #include "Request.h"
 #include "Segment.h"
 #include "HttpRequest.h"
@@ -101,7 +98,7 @@ std::string HttpResponse::determinFilename() const
     util::getContentDispositionFilename
     (httpHeader->getFirst(HttpHeader::CONTENT_DISPOSITION));
   if(contentDisposition.empty()) {
-    std::string file = util::urldecode(httpRequest->getFile());
+    std::string file = util::percentDecode(httpRequest->getFile());
     if(file.empty()) {
       return "index.html";
     } else {
@@ -116,9 +113,9 @@ std::string HttpResponse::determinFilename() const
 
 void HttpResponse::retrieveCookie()
 {
-  std::deque<std::string> v = httpHeader->get(HttpHeader::SET_COOKIE);
-  for(std::deque<std::string>::const_iterator itr = v.begin(); itr != v.end();
-      ++itr) {
+  std::vector<std::string> v = httpHeader->get(HttpHeader::SET_COOKIE);
+  for(std::vector<std::string>::const_iterator itr = v.begin(), eoi = v.end();
+      itr != eoi; ++itr) {
     httpRequest->getCookieStorage()->parseAndStore(*itr,
                                                    httpRequest->getHost(),
                                                    httpRequest->getDir());
@@ -135,14 +132,14 @@ bool HttpResponse::isRedirect() const
 void HttpResponse::processRedirect()
 {
   
-  if(httpRequest->getRequest()->redirectUrl(getRedirectURI())) {
+  if(httpRequest->getRequest()->redirectUri(getRedirectURI())) {
     logger->info(MSG_REDIRECT, cuid,
-                 httpRequest->getRequest()->getCurrentUrl().c_str());
+                 httpRequest->getRequest()->getCurrentUri().c_str());
   } else {
     throw DL_RETRY_EX
       (StringFormat("CUID#%d - Redirect to %s failed. It may not be a valid"
                     " URI.", cuid,
-                    httpRequest->getRequest()->getCurrentUrl().c_str()).str());
+                    httpRequest->getRequest()->getCurrentUri().c_str()).str());
   }
 }
 
