@@ -66,18 +66,22 @@ namespace aria2 {
 # define SA_RESETHAND 0x80000000
 #endif // SA_RESETHAND
 
+namespace global {
+
 extern volatile sig_atomic_t globalHaltRequested;
 
+} // namespace global
+
 static void handler(int signal) {
-  if(globalHaltRequested == 0) {
-    globalHaltRequested = 1;
-  } else if(globalHaltRequested == 2) {
-    globalHaltRequested = 3;
+  if(global::globalHaltRequested == 0) {
+    global::globalHaltRequested = 1;
+  } else if(global::globalHaltRequested == 2) {
+    global::globalHaltRequested = 3;
   }
 }
 
 MultiUrlRequestInfo::MultiUrlRequestInfo
-(const RequestGroups& requestGroups,
+(const std::vector<SharedHandle<RequestGroup> >& requestGroups,
  const SharedHandle<Option>& op,
  const SharedHandle<StatCalc>& statCalc,
  std::ostream& summaryOut)
@@ -190,6 +194,9 @@ downloadresultcode::RESULT MultiUrlRequestInfo::execute()
       }
     }
   } catch(RecoverableException& e) {
+    if(returnValue == downloadresultcode::FINISHED) {
+      returnValue = downloadresultcode::UNKNOWN_ERROR;
+    }
     _logger->error(EX_EXCEPTION_CAUGHT, e);
   }
 #ifdef SIGHUP
