@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,7 +38,7 @@
 #include "common.h"
 
 #include <string>
-#include <deque>
+#include <vector>
 
 #include "SharedHandle.h"
 #include "TimeA2.h"
@@ -77,7 +77,7 @@ public:
    */
   virtual SharedHandle<Piece> getMissingPiece
   (const SharedHandle<Peer>& peer,
-   const std::deque<size_t>& excludedIndexes) = 0;
+   const std::vector<size_t>& excludedIndexes) = 0;
 
   /**
    * Returns a piece that the peer has but localhost doesn't.
@@ -95,7 +95,7 @@ public:
    */
   virtual SharedHandle<Piece> getMissingFastPiece
   (const SharedHandle<Peer>& peer,
-   const std::deque<size_t>& excludedIndexes) = 0;
+   const std::vector<size_t>& excludedIndexes) = 0;
 
 #endif // ENABLE_BITTORRENT
 
@@ -180,7 +180,7 @@ public:
   virtual const unsigned char* getBitfield() = 0;
 
   virtual void setBitfield(const unsigned char* bitfield,
-			   size_t bitfieldLength) = 0;
+                           size_t bitfieldLength) = 0;
   
   virtual size_t getBitfieldLength() = 0;
 
@@ -204,9 +204,9 @@ public:
    * indexes is filled with piece index which is not advertised by the caller
    * command and newer than lastCheckTime.
    */
-  virtual void getAdvertisedPieceIndexes(std::deque<size_t>& indexes,
-					 int32_t myCuid,
-					 const Time& lastCheckTime) = 0;
+  virtual void getAdvertisedPieceIndexes(std::vector<size_t>& indexes,
+                                         int32_t myCuid,
+                                         const Time& lastCheckTime) = 0;
 
   /**
    * Removes have entry if specified seconds have elapsed since its
@@ -225,23 +225,23 @@ public:
   virtual void markPiecesDone(uint64_t length) = 0;
 
   virtual void
-  addInFlightPiece(const std::deque<SharedHandle<Piece> >& pieces) = 0;
+  addInFlightPiece(const std::vector<SharedHandle<Piece> >& pieces) = 0;
 
   virtual size_t countInFlightPiece() = 0;
 
-  virtual void getInFlightPieces(std::deque<SharedHandle<Piece> >& pieces) = 0;
+  virtual void getInFlightPieces(std::vector<SharedHandle<Piece> >& pieces) = 0;
 
   virtual void addPieceStats(size_t index) = 0;
 
   virtual void addPieceStats(const unsigned char* bitfield,
-			     size_t bitfieldLength) = 0;
+                             size_t bitfieldLength) = 0;
 
   virtual void subtractPieceStats(const unsigned char* bitfield,
-				  size_t bitfieldLength) = 0;
+                                  size_t bitfieldLength) = 0;
 
   virtual void updatePieceStats(const unsigned char* newBitfield,
-				size_t newBitfieldLength,
-				const unsigned char* oldBitfield) = 0;
+                                size_t newBitfieldLength,
+                                const unsigned char* oldBitfield) = 0;
 
 };
 
