@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -34,9 +34,14 @@
 /* copyright --> */
 #include "SimpleBtMessage.h"
 #include "message.h"
-#include "BtRegistry.h"
+#include "Peer.h"
+#include "PeerConnection.h"
+#include "Logger.h"
 
-SimpleBtMessage::SimpleBtMessage():leftDataLength(0) {}
+namespace aria2 {
+
+SimpleBtMessage::SimpleBtMessage(uint8_t id, const std::string& name):
+  AbstractBtMessage(id, name) {}
 
 SimpleBtMessage::~SimpleBtMessage() {}
 
@@ -44,21 +49,27 @@ void SimpleBtMessage::send() {
   if(invalidate) {
     return;
   }
-  if(sendPredicate() || sendingInProgress) {
-    const unsigned char* msg = getMessage();
-    int32_t msgLength = getMessageLength();
-    if(!sendingInProgress) {
+  if(!sendPredicate() && !sendingInProgress) {
+    return;
+  }
+  if(!sendingInProgress) {
+    if(logger->info()) {
       logger->info(MSG_SEND_PEER_MESSAGE,
-		   cuid, peer->ipaddr.c_str(), peer->port, toString().c_str());
-      leftDataLength = getMessageLength();
+                   cuid, peer->ipaddr.c_str(), peer->port, toString().c_str());
     }
-    sendingInProgress = false;
-    int32_t writtenLength = peerConnection->sendMessage(msg+msgLength-leftDataLength, leftDataLength);
-    if(writtenLength == leftDataLength) {
-      onSendComplete();
-    } else {
-      leftDataLength -= writtenLength;
-      sendingInProgress = true;
+    unsigned char* msg = createMessage();
+    size_t msgLength = getMessageLength();
+    if(logger->debug()) {
+      logger->debug("msglength = %lu bytes",
+                    static_cast<unsigned long>(msgLength));
     }
+    peerConnection->pushBytes(msg, msgLength);
+  }
+  peerConnection->sendPendingData();
+  sendingInProgress = !peerConnection->sendBufferIsEmpty();
+  if(!sendingInProgress) {
+    onSendComplete();
   }
 }
+
+} // namespace aria2
