@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -57,19 +57,13 @@ private:
 
   void changeSw();
 public:
-  SpeedCalc() {
-    reset();
-  }
-
-  ~SpeedCalc() {}
+  SpeedCalc();
 
   /**
    * Returns download/upload speed in byte per sec
    */
   unsigned int calculateSpeed();
 
-  unsigned int calculateSpeed(const struct timeval& now);
-
   unsigned int getMaxSpeed() const {
     return maxSpeed;
   }
