@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -132,15 +132,15 @@ const std::string METADATA_SIZE("metadataSize");
 const std::string METADATA("metadata");
 
 static void extractPieceHash(const SharedHandle<DownloadContext>& ctx,
-			     const std::string& hashData,
-			     size_t hashLength,
-			     size_t numPieces)
+                             const std::string& hashData,
+                             size_t hashLength,
+                             size_t numPieces)
 {
   std::vector<std::string> pieceHashes;
   pieceHashes.reserve(numPieces);
   for(size_t i = 0; i < numPieces; ++i) {
     pieceHashes.push_back(util::toHex(hashData.data()+i*hashLength,
-				      hashLength));
+                                      hashLength));
   }
   ctx->setPieceHashes(pieceHashes.begin(), pieceHashes.end());
   ctx->setPieceHashAlgo(MessageDigestContext::SHA1);
@@ -150,10 +150,10 @@ static void extractUrlList
 (BDE& torrent, std::vector<std::string>& uris, const BDE& bde)
 {
   if(bde.isList()) {
-    for(BDE::List::const_iterator itr = bde.listBegin();
-	itr != bde.listEnd(); ++itr) {
+    for(BDE::List::const_iterator itr = bde.listBegin(), eoi = bde.listEnd();
+        itr != eoi; ++itr) {
       if((*itr).isString()) {
-	uris.push_back((*itr).s());
+        uris.push_back((*itr).s());
       }
     }
     torrent[URL_LIST] = bde;
@@ -200,19 +200,18 @@ static void extractFileEntries
     }
     const BDE& nameData = infoDict[nameKey];
     if(nameData.isString()) {
-      // Split path by '/' just in case nasty ".." is included in name
-      std::vector<std::string> pathelems;
-      util::split(nameData.s(), std::back_inserter(pathelems), "/");
-      name = util::joinPath(pathelems.begin(), pathelems.end());
-      torrent[NAME] = nameData.s();
+      if(util::detectDirTraversal(nameData.s())) {
+        throw DL_ABORT_EX
+          (StringFormat(MSG_DIR_TRAVERSAL_DETECTED,nameData.s().c_str()).str());
+      }
+      name = nameData.s();
     } else {
       name = strconcat(File(defaultName).getBasename(), ".file");
-      torrent[NAME] = name;
     }
   } else {
     name = overrideName;
-    torrent[NAME] = name;
   }
+  torrent[NAME] = name;
 
   const BDE& filesList = infoDict[C_FILES];
   std::vector<SharedHandle<FileEntry> > fileEntries;
@@ -222,47 +221,46 @@ static void extractFileEntries
     off_t offset = 0;
     // multi-file mode
     torrent[MODE] = MULTI;
-    for(BDE::List::const_iterator itr = filesList.listBegin();
-	itr != filesList.listEnd(); ++itr) {
+    for(BDE::List::const_iterator itr = filesList.listBegin(),
+          eoi = filesList.listEnd(); itr != eoi; ++itr) {
       const BDE& fileDict = *itr;
       if(!fileDict.isDict()) {
-	continue;
+        continue;
       }
       const BDE& fileLengthData = fileDict[C_LENGTH];
       if(!fileLengthData.isInteger()) {
-	throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-				       C_LENGTH.c_str()).str());
+        throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
+                                       C_LENGTH.c_str()).str());
       }
       length += fileLengthData.i();
 
       std::string pathKey;
       if(fileDict.containsKey(C_PATH_UTF8)) {
-	pathKey = C_PATH_UTF8;
+        pathKey = C_PATH_UTF8;
       } else {
-	pathKey = C_PATH;
+        pathKey = C_PATH;
       }
       const BDE& pathList = fileDict[pathKey];
       if(!pathList.isList() || pathList.empty()) {
-	throw DL_ABORT_EX("Path is empty.");
+        throw DL_ABORT_EX("Path is empty.");
       }
       
-      std::vector<std::string> pathelem(pathList.size());
-      std::transform(pathList.listBegin(), pathList.listEnd(), pathelem.begin(),
-		     std::mem_fun_ref(&BDE::s));
-      std::string path = name;
-      strappend(path, "/", util::joinPath(pathelem.begin(), pathelem.end()));
-      // Split path with '/' again because each pathList element can
-      // contain "/" inside.
-      std::vector<std::string> elements;
-      util::split(path, std::back_inserter(elements), "/");
-      path = util::joinPath(elements.begin(), elements.end());
-
-      std::deque<std::string> uris;
+      std::vector<std::string> pathelem(pathList.size()+1);
+      pathelem[0] = name;
+      std::transform(pathList.listBegin(), pathList.listEnd(),
+                     pathelem.begin()+1, std::mem_fun_ref(&BDE::s));
+      std::string path = strjoin(pathelem.begin(), pathelem.end(), '/');
+      if(util::detectDirTraversal(path)) {
+        throw DL_ABORT_EX
+          (StringFormat(MSG_DIR_TRAVERSAL_DETECTED, path.c_str()).str());
+      }
+      std::vector<std::string> uris;
       createUri(urlList.begin(), urlList.end(), std::back_inserter(uris), path);
       SharedHandle<FileEntry> fileEntry
-	(new FileEntry(strconcat(ctx->getDir(), "/", path),
-		       fileLengthData.i(),
-		       offset, uris));
+        (new FileEntry(util::applyDir(ctx->getDir(), util::escapePath(path)),
+                       fileLengthData.i(),
+                       offset, uris));
+      fileEntry->setOriginalName(path);
       fileEntries.push_back(fileEntry);
       offset += fileEntry->getLength();
     }
@@ -271,31 +269,33 @@ static void extractFileEntries
     torrent[MODE] = SINGLE;
     const BDE& lengthData = infoDict[C_LENGTH];
     if(!lengthData.isInteger()) {
-	throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-				       C_LENGTH.c_str()).str());      
+      throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
+                                     C_LENGTH.c_str()).str());      
     }
     uint64_t totalLength = lengthData.i();
 
     // For each uri in urlList, if it ends with '/', then
     // concatenate name to it. Specification just says so.
-    std::deque<std::string> uris;
-    for(std::vector<std::string>::const_iterator i = urlList.begin();
-	i != urlList.end(); ++i) {
-      if(util::endsWith(*i, "/")) {
-	uris.push_back((*i)+name);
+    std::vector<std::string> uris;
+    for(std::vector<std::string>::const_iterator i = urlList.begin(),
+          eoi = urlList.end(); i != eoi; ++i) {
+      if(util::endsWith(*i, A2STR::SLASH_C)) {
+        uris.push_back((*i)+name);
       } else {
-	uris.push_back(*i);
+        uris.push_back(*i);
       }
     }
 
     SharedHandle<FileEntry> fileEntry
-      (new FileEntry(strconcat(ctx->getDir(), "/", name),totalLength, 0,
-		     uris));
+      (new FileEntry(util::applyDir(ctx->getDir(), util::escapePath(name)),
+                     totalLength, 0,
+                     uris));
+    fileEntry->setOriginalName(name);
     fileEntries.push_back(fileEntry);
   }
   ctx->setFileEntries(fileEntries.begin(), fileEntries.end());
   if(torrent[MODE].s() == MULTI) {
-    ctx->setBasePath(strconcat(ctx->getDir(), "/", name));
+    ctx->setBasePath(util::applyDir(ctx->getDir(), name));
   }
 }
 
@@ -305,13 +305,13 @@ static void extractAnnounce(BDE& torrent, const BDE& rootDict)
   if(announceList.isList()) {
     torrent[ANNOUNCE_LIST] = announceList;
     BDE& tiers = torrent[ANNOUNCE_LIST];
-    for(BDE::List::iterator tieriter = tiers.listBegin();
-	tieriter != tiers.listEnd(); ++tieriter) {
-      for(BDE::List::iterator uriiter = (*tieriter).listBegin();
-	  uriiter != (*tieriter).listEnd(); ++uriiter) {
-	if((*uriiter).isString()) {
-	  *uriiter = util::trim((*uriiter).s());
-	}
+    for(BDE::List::iterator tieriter = tiers.listBegin(),
+          eoi = tiers.listEnd(); tieriter != eoi; ++tieriter) {
+      for(BDE::List::iterator uriiter = (*tieriter).listBegin(),
+            eoi2 = (*tieriter).listEnd(); uriiter != eoi2; ++uriiter) {
+        if((*uriiter).isString()) {
+          *uriiter = util::trim((*uriiter).s());
+        }
       }
     }
   } else {
@@ -329,22 +329,22 @@ static void extractNodes(BDE& torrent, const BDE& nodesList)
 {
   BDE nodes = BDE::list();
   if(nodesList.isList()) {
-    for(BDE::List::const_iterator i = nodesList.listBegin();
-	i != nodesList.listEnd(); ++i) {
+    for(BDE::List::const_iterator i = nodesList.listBegin(),
+          eoi = nodesList.listEnd(); i != eoi; ++i) {
       const BDE& addrPairList = (*i);
       if(!addrPairList.isList() || addrPairList.size() != 2) {
-	continue;
+        continue;
       }
       const BDE& hostname = addrPairList[0];
       if(!hostname.isString()) {
-	continue;
+        continue;
       }
       if(util::trim(hostname.s()).empty()) {
-	continue;
+        continue;
       }
       const BDE& port = addrPairList[1];
       if(!port.isInteger() || !(0 < port.i() && port.i() < 65536)) {
-	continue;
+        continue;
       }
       BDE node = BDE::dict();
       node[HOSTNAME] = hostname;
@@ -360,7 +360,7 @@ static void processRootDictionary
  const BDE& rootDict,
  const std::string& defaultName,
  const std::string& overrideName,
- const std::deque<std::string>& uris)
+ const std::vector<std::string>& uris)
 {
   if(!rootDict.isDict()) {
     throw DL_ABORT_EX("torrent file does not contain a root dictionary.");
@@ -368,7 +368,7 @@ static void processRootDictionary
   const BDE& infoDict = rootDict[C_INFO];
   if(!infoDict.isDict()) {
     throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-				   C_INFO.c_str()).str());
+                                   C_INFO.c_str()).str());
   }
   BDE torrent = BDE::dict();
 
@@ -376,9 +376,9 @@ static void processRootDictionary
   std::string encodedInfoDict = bencode::encode(infoDict);
   unsigned char infoHash[INFO_HASH_LENGTH];
   MessageDigestHelper::digest(infoHash, INFO_HASH_LENGTH,
-			      MessageDigestContext::SHA1,
-			      encodedInfoDict.data(),
-			      encodedInfoDict.size());
+                              MessageDigestContext::SHA1,
+                              encodedInfoDict.data(),
+                              encodedInfoDict.size());
   torrent[INFO_HASH] = std::string(&infoHash[0], &infoHash[INFO_HASH_LENGTH]);
   torrent[METADATA] = encodedInfoDict;
   torrent[METADATA_SIZE] = encodedInfoDict.size();
@@ -387,7 +387,7 @@ static void processRootDictionary
   const BDE& piecesData = infoDict[C_PIECES];
   if(!piecesData.isString()) {
     throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-				   C_PIECES.c_str()).str());
+                                   C_PIECES.c_str()).str());
   }
   // Commented out To download 0 length torrent.
   //   if(piecesData.s().empty()) {
@@ -402,7 +402,7 @@ static void processRootDictionary
   const BDE& pieceLengthData = infoDict[C_PIECE_LENGTH];
   if(!pieceLengthData.isInteger()) {
     throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-				   C_PIECE_LENGTH.c_str()).str());
+                                   C_PIECE_LENGTH.c_str()).str());
   }
   size_t pieceLength = pieceLengthData.i();
   ctx->setPieceLength(pieceLength);
@@ -458,72 +458,72 @@ static void processRootDictionary
 }
 
 void load(const std::string& torrentFile,
-	  const SharedHandle<DownloadContext>& ctx,
-	  const std::string& overrideName)
+          const SharedHandle<DownloadContext>& ctx,
+          const std::string& overrideName)
 {
   processRootDictionary(ctx,
-			bencode::decodeFromFile(torrentFile),
-			torrentFile,
-			overrideName,
-			std::deque<std::string>());
+                        bencode::decodeFromFile(torrentFile),
+                        torrentFile,
+                        overrideName,
+                        std::vector<std::string>());
 }
 
 void load(const std::string& torrentFile,
-	  const SharedHandle<DownloadContext>& ctx,
-	  const std::deque<std::string>& uris,
-	  const std::string& overrideName)
+          const SharedHandle<DownloadContext>& ctx,
+          const std::vector<std::string>& uris,
+          const std::string& overrideName)
 {
   processRootDictionary(ctx,
-			bencode::decodeFromFile(torrentFile),
-			torrentFile,
-			overrideName,
-			uris);
+                        bencode::decodeFromFile(torrentFile),
+                        torrentFile,
+                        overrideName,
+                        uris);
 }
 
 void loadFromMemory(const unsigned char* content,
-		    size_t length,
-		    const SharedHandle<DownloadContext>& ctx,
-		    const std::string& defaultName,
-		    const std::string& overrideName)
+                    size_t length,
+                    const SharedHandle<DownloadContext>& ctx,
+                    const std::string& defaultName,
+                    const std::string& overrideName)
 {
   processRootDictionary(ctx,
-			bencode::decode(content, length),
-			defaultName,
-			overrideName,
-			std::deque<std::string>());
+                        bencode::decode(content, length),
+                        defaultName,
+                        overrideName,
+                        std::vector<std::string>());
 }
 
 void loadFromMemory(const unsigned char* content,
-		    size_t length,
-		    const SharedHandle<DownloadContext>& ctx,
-		    const std::deque<std::string>& uris,
-		    const std::string& defaultName,
-		    const std::string& overrideName)
+                    size_t length,
+                    const SharedHandle<DownloadContext>& ctx,
+                    const std::vector<std::string>& uris,
+                    const std::string& defaultName,
+                    const std::string& overrideName)
 {
   processRootDictionary(ctx,
-			bencode::decode(content, length),
-			defaultName,
-			overrideName,
-			uris);
+                        bencode::decode(content, length),
+                        defaultName,
+                        overrideName,
+                        uris);
 }
 
 void loadFromMemory(const std::string& context,
-		    const SharedHandle<DownloadContext>& ctx,
-		    const std::string& defaultName,
-		    const std::string& overrideName)
+                    const SharedHandle<DownloadContext>& ctx,
+                    const std::string& defaultName,
+                    const std::string& overrideName)
 {
   processRootDictionary
     (ctx,
      bencode::decode(context),
      defaultName, overrideName,
-     std::deque<std::string>());
+     std::vector<std::string>());
 }
 
 void loadFromMemory(const std::string& context,
-		    const SharedHandle<DownloadContext>& ctx,
-		    const std::deque<std::string>& uris,
-		    const std::string& defaultName,
-		    const std::string& overrideName)
+                    const SharedHandle<DownloadContext>& ctx,
+                    const std::vector<std::string>& uris,
+                    const std::string& defaultName,
+                    const std::string& overrideName)
 {
   processRootDictionary
     (ctx,
@@ -567,13 +567,13 @@ void print(std::ostream& o, const SharedHandle<DownloadContext>& dctx)
   o << "Mode: " << torrentAttrs[MODE].s() << "\n";
   o << "Announce:" << "\n";
   const BDE& announceList = torrentAttrs[ANNOUNCE_LIST];
-  for(BDE::List::const_iterator tieritr = announceList.listBegin();
-      tieritr != announceList.listEnd(); ++tieritr) {
+  for(BDE::List::const_iterator tieritr = announceList.listBegin(),
+        eoi = announceList.listEnd(); tieritr != eoi; ++tieritr) {
     if(!(*tieritr).isList()) {
       continue;
     }
-    for(BDE::List::const_iterator i = (*tieritr).listBegin();
-	i != (*tieritr).listEnd(); ++i) {
+    for(BDE::List::const_iterator i = (*tieritr).listBegin(),
+          eoi2 = (*tieritr).listEnd(); i != eoi2; ++i) {
       o << " " << (*i).s();
     }
     o << "\n";
@@ -586,8 +586,8 @@ void print(std::ostream& o, const SharedHandle<DownloadContext>& dctx)
   if(!torrentAttrs[URL_LIST].empty()) {
     const BDE& urlList = torrentAttrs[URL_LIST];
     o << "URL List: " << "\n";
-    for(BDE::List::const_iterator i = urlList.listBegin();
-	i != urlList.listEnd(); ++i) {
+    for(BDE::List::const_iterator i = urlList.listBegin(),
+          eoi = urlList.listEnd(); i != eoi; ++i) {
       o << " " << (*i).s() << "\n";
     }
   }
@@ -626,7 +626,7 @@ void computeFastSet
       uint32_t y = ntohl(ny);
       size_t index = y%numPieces;
       if(std::find(fastSet.begin(), fastSet.end(), index) == fastSet.end()) {
-	fastSet.push_back(index);
+        fastSet.push_back(index);
       }
     }
     unsigned char temp[20];
@@ -700,7 +700,7 @@ void checkIndex(size_t index, size_t pieces)
 {
   if(!(index < pieces)) {
     throw DL_ABORT_EX(StringFormat("Invalid index: %lu",
-				 static_cast<unsigned long>(index)).str());
+                                   static_cast<unsigned long>(index)).str());
   }
 }
 
@@ -716,13 +716,13 @@ void checkLength(size_t length)
   if(length > MAX_BLOCK_LENGTH) {
     throw DL_ABORT_EX
       (StringFormat("Length too long: %lu > %uKB",
-		    static_cast<unsigned long>(length),
-		    MAX_BLOCK_LENGTH/1024).str());
+                    static_cast<unsigned long>(length),
+                    MAX_BLOCK_LENGTH/1024).str());
   }
   if(length == 0) {
     throw DL_ABORT_EX
       (StringFormat("Invalid length: %lu",
-		    static_cast<unsigned long>(length)).str());
+                    static_cast<unsigned long>(length)).str());
   }
 }
 
@@ -731,15 +731,15 @@ void checkRange(uint32_t begin, size_t length, size_t pieceLength)
   if(!(0 < length)) {
     throw DL_ABORT_EX
       (StringFormat("Invalid range: begin=%u, length=%lu",
-		    begin,
-		    static_cast<unsigned long>(length)).str());
+                    begin,
+                    static_cast<unsigned long>(length)).str());
   }
   uint32_t end = begin+length;
   if(!(end <= pieceLength)) {
     throw DL_ABORT_EX
       (StringFormat("Invalid range: begin=%u, length=%lu",
-		    begin,
-		    static_cast<unsigned long>(length)).str());
+                    begin,
+                    static_cast<unsigned long>(length)).str());
   }
 }
 
@@ -749,11 +749,11 @@ void checkBitfield
   if(!(bitfieldLength == (pieces+7)/8)) {
     throw DL_ABORT_EX
       (StringFormat("Invalid bitfield length: %lu",
-		    static_cast<unsigned long>(bitfieldLength)).str());
+                    static_cast<unsigned long>(bitfieldLength)).str());
   }
   // Check if last byte contains garbage set bit.
   if(bitfield[bitfieldLength-1]&~bitfield::lastByteMask(pieces)) {
-      throw DL_ABORT_EX("Invalid bitfield");
+    throw DL_ABORT_EX("Invalid bitfield");
   }
 }
 
@@ -811,15 +811,15 @@ std::pair<std::string, uint16_t> unpackcompact(const unsigned char* compact)
   char host[NI_MAXHOST];
   int s;
   s = getnameinfo(reinterpret_cast<const struct sockaddr*>(&in), sizeof(in),
-		  host, NI_MAXHOST, 0, NI_MAXSERV,
-		  NI_NUMERICHOST);
+                  host, NI_MAXHOST, 0, NI_MAXSERV,
+                  NI_NUMERICHOST);
   if(s) {
     return std::pair<std::string, uint16_t>();
   }
   uint16_t port_nworder;
   memcpy(&port_nworder, compact+sizeof(uint32_t), sizeof(uint16_t));
   uint16_t port = ntohs(port_nworder);
-  return std::pair<std::string, uint16_t>(host, port);
+  return std::make_pair(host, port);
 }
 
 
@@ -838,7 +838,7 @@ void assertPayloadLengthEqual
   if(expected != actual) {
     throw DL_ABORT_EX
       (StringFormat(EX_INVALID_PAYLOAD_SIZE, msgName.c_str(),
-		    actual, expected).str());
+                    actual, expected).str());
   }
 }
 
@@ -849,17 +849,10 @@ void assertID
   if(expected != id) {
     throw DL_ABORT_EX
       (StringFormat(EX_INVALID_BT_MESSAGE_ID, id, msgName.c_str(),
-		    expected).str());
+                    expected).str());
   }
 }
 
-void generateRandomKey(unsigned char* key)
-{
-  unsigned char bytes[40];
-  util::generateRandomData(bytes, sizeof(bytes));
-  MessageDigestHelper::digest(key, 20, MessageDigestContext::SHA1, bytes, sizeof(bytes));
-}
-
 BDE parseMagnet(const std::string& magnet)
 {
   BDE result;
@@ -870,31 +863,35 @@ BDE parseMagnet(const std::string& magnet)
   if(!r.containsKey("xt")) {
     throw DL_ABORT_EX("Missing xt parameter in Magnet URI.");
   }
+  std::string infoHash;
   const BDE& xts = r["xt"];
-  if(xts.size() == 0 || !util::startsWith(xts[0].s(), "urn:btih:")) {
-    throw DL_ABORT_EX("Bad BitTorrent Magnet URI.");
+  for(BDE::List::const_iterator xtiter = xts.listBegin(),
+        eoi = xts.listEnd(); xtiter != eoi && infoHash.empty(); ++xtiter) {
+    if(util::startsWith((*xtiter).s(), "urn:btih:")) {
+      std::string xtarg = (*xtiter).s().substr(9);
+      size_t size = xtarg.size();
+      if(size == 32) {
+        std::string rawhash = base32::decode(xtarg);
+        if(rawhash.size() == 20) {
+          infoHash.swap(rawhash);
+        }
+      } else if(size == 40) {
+        std::string rawhash = util::fromHex(xtarg);
+        if(!rawhash.empty()) {
+          infoHash.swap(rawhash);
+        }
+      }
+    }
   }
-  std::string infoHash = xts[0].s().substr(9);
-  if(infoHash.size() == 32) {
-    std::string rawhash = base32::decode(infoHash);
-    if(rawhash.size() != 20) {
-      throw DL_ABORT_EX("Invalid BitTorrent Info Hash.");
-    }
-    infoHash = rawhash;
-  } else if(infoHash.size() == 40) {
-    std::string rawhash = util::fromHex(infoHash);
-    if(rawhash.empty()) {
-      throw DL_ABORT_EX("Invalid BitTorrent Info Hash.");
-    }
-    infoHash = rawhash;
-  } else {
-    throw DL_ABORT_EX("Invalid BitTorrent Info Hash.");
+  if(infoHash.empty()) {
+    throw DL_ABORT_EX("Bad BitTorrent Magnet URI. "
+                      "No valid BitTorrent Info Hash found.");
   }
   BDE announceList = BDE::list();
   if(r.containsKey("tr")) {
     const BDE& uris = r["tr"];
-    for(BDE::List::const_iterator i = uris.listBegin(); i != uris.listEnd();
-	++i) {
+    for(BDE::List::const_iterator i = uris.listBegin(), eoi = uris.listEnd();
+        i != eoi; ++i) {
       BDE tier = BDE::list();
       tier << *i;
       announceList << tier;
@@ -947,16 +944,16 @@ std::string torrent2Magnet(const BDE& attrs)
   }
   if(attrs.containsKey(NAME)) {
     uri += "&dn=";
-    uri += util::urlencode(attrs[NAME].s());
+    uri += util::percentEncode(attrs[NAME].s());
   }
   if(attrs.containsKey(ANNOUNCE_LIST)) {
     const BDE& tiers = attrs[ANNOUNCE_LIST];
-    for(BDE::List::const_iterator tieriter = tiers.listBegin();
-	tieriter != tiers.listEnd(); ++tieriter) {
-      for(BDE::List::const_iterator uriiter = (*tieriter).listBegin();
-	  uriiter != (*tieriter).listEnd(); ++uriiter) {
-	uri += "&tr=";
-	uri += util::urlencode((*uriiter).s());
+    for(BDE::List::const_iterator tieriter = tiers.listBegin(),
+          eoi = tiers.listEnd(); tieriter != eoi; ++tieriter) {
+      for(BDE::List::const_iterator uriiter = (*tieriter).listBegin(),
+            eoi2 = (*tieriter).listEnd(); uriiter != eoi2; ++uriiter) {
+        uri += "&tr=";
+        uri += util::percentEncode((*uriiter).s());
       }
     }
   }
