@@ -27,14 +27,14 @@ private:
   bool _allDownloadFinished;
 public:
   MockPieceStorage():totalLength(0),
-		     filteredTotalLength(0),
-		     completedLength(0),
-		     filteredCompletedLength(0),
-		     bitfieldMan(0),
-		     selectiveDownloadingMode(false),
-		     endGame(false),
-		     _downloadFinished(false),
-		     _allDownloadFinished(false) {}
+                     filteredTotalLength(0),
+                     completedLength(0),
+                     filteredCompletedLength(0),
+                     bitfieldMan(0),
+                     selectiveDownloadingMode(false),
+                     endGame(false),
+                     _downloadFinished(false),
+                     _allDownloadFinished(false) {}
 
   virtual ~MockPieceStorage() {}
 
@@ -49,7 +49,7 @@ public:
   }
 
   virtual SharedHandle<Piece> getMissingPiece
-  (const SharedHandle<Peer>& peer, const std::deque<size_t>& excludedIndexes)
+  (const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes)
   {
     return SharedHandle<Piece>(new Piece());
   }
@@ -59,7 +59,7 @@ public:
   }
 
   virtual SharedHandle<Piece> getMissingFastPiece
-  (const SharedHandle<Peer>& peer, const std::deque<size_t>& excludedIndexes)
+  (const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes)
   {
     return SharedHandle<Piece>(new Piece());
   }
@@ -164,7 +164,7 @@ public:
   }
 
   virtual void setBitfield(const unsigned char* bitfield,
-			   size_t bitfieldLength) {
+                           size_t bitfieldLength) {
     bitfieldMan->setBitfield(bitfield, bitfieldLength);
   }
   
@@ -212,16 +212,16 @@ public:
 
   virtual void advertisePiece(int32_t cuid, size_t index) {}
 
-  virtual void getAdvertisedPieceIndexes(std::deque<size_t>& indexes,
-					 int32_t myCuid,
-					 const Time& lastCheckTime)
+  virtual void getAdvertisedPieceIndexes(std::vector<size_t>& indexes,
+                                         int32_t myCuid,
+                                         const Time& lastCheckTime)
   {}
 
   virtual void removeAdvertisedPiece(time_t elapsed) {}
 
   virtual void markAllPiecesDone() {}
 
-  virtual void addInFlightPiece(const std::deque<SharedHandle<Piece> >& pieces)
+  virtual void addInFlightPiece(const std::vector<SharedHandle<Piece> >& pieces)
   {
     std::copy(pieces.begin(), pieces.end(), back_inserter(inFlightPieces));
   }
@@ -231,7 +231,7 @@ public:
     return inFlightPieces.size();
   }
 
-  virtual void getInFlightPieces(std::deque<SharedHandle<Piece> >& pieces)
+  virtual void getInFlightPieces(std::vector<SharedHandle<Piece> >& pieces)
   {
     pieces.insert(pieces.end(), inFlightPieces.begin(), inFlightPieces.end());
   }
@@ -239,14 +239,14 @@ public:
   virtual void addPieceStats(size_t index) {}
 
   virtual void addPieceStats(const unsigned char* bitfield,
-			     size_t bitfieldLength) {}
+                             size_t bitfieldLength) {}
 
   virtual void subtractPieceStats(const unsigned char* bitfield,
-				  size_t bitfieldLength) {}
+                                  size_t bitfieldLength) {}
 
   virtual void updatePieceStats(const unsigned char* newBitfield,
-				size_t newBitfieldLength,
-				const unsigned char* oldBitfield) {}
+                                size_t newBitfieldLength,
+                                const unsigned char* oldBitfield) {}
 };
 
 } // namespace aria2
