@@ -24,6 +24,7 @@ class OptionParserTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testFindByID);
   CPPUNIT_TEST(testParseDefaultValues);
   CPPUNIT_TEST(testParseArg);
+  CPPUNIT_TEST(testParse);
   CPPUNIT_TEST_SUITE_END();
 private:
   SharedHandle<OptionParser> _oparser;
@@ -34,7 +35,7 @@ public:
 
     SharedHandle<OptionHandler> alpha
       (new DefaultOptionHandler("alpha", NO_DESCRIPTION, "ALPHA", "",
-				OptionHandler::REQ_ARG, 'A'));
+                                OptionHandler::REQ_ARG, 'A'));
     alpha->addTag("apple");
     _oparser->addOptionHandler(alpha);
 
@@ -46,7 +47,7 @@ public:
 
     SharedHandle<DefaultOptionHandler> charlie
       (new DefaultOptionHandler("charlie", NO_DESCRIPTION, "CHARLIE", "",
-				OptionHandler::REQ_ARG, 'C'));
+                                OptionHandler::REQ_ARG, 'C'));
     charlie->hide();
     charlie->addTag("pineapple");
     _oparser->addOptionHandler(charlie);
@@ -67,6 +68,7 @@ public:
   void testFindByID();
   void testParseDefaultValues();
   void testParseArg();
+  void testParse();
 };
 
 
@@ -107,6 +109,9 @@ void OptionParserTest::testFindByName()
 
   SharedHandle<OptionHandler> charlie = _oparser->findByName("charlie");
   CPPUNIT_ASSERT(charlie.isNull());
+
+  SharedHandle<OptionHandler> alpha2 = _oparser->findByName("alpha2");
+  CPPUNIT_ASSERT(alpha2.isNull());
 }
 
 void OptionParserTest::testFindByShortName()
@@ -158,20 +163,34 @@ void OptionParserTest::testParseArg()
   strncpy(nonopt2, "nonopt2", sizeof(nonopt2));
 
   char* const argv[] = { prog, optionAlpha, argAlpha, optionBravo, argBravo,
-			 nonopt1, nonopt2 };
+                         nonopt1, nonopt2 };
   int argc = arrayLength(argv);
 
   std::stringstream s;
-  std::deque<std::string> nonopts;
+  std::vector<std::string> nonopts;
 
   _oparser->parseArg(s, nonopts, argc, argv);
 
   CPPUNIT_ASSERT_EQUAL(std::string("alpha=ALPHA\n"
-				   "bravo=BRAVO\n"), s.str());
+                                   "bravo=BRAVO\n"), s.str());
 
   CPPUNIT_ASSERT_EQUAL((size_t)2, nonopts.size());
   CPPUNIT_ASSERT_EQUAL(std::string("nonopt1"), nonopts[0]);
   CPPUNIT_ASSERT_EQUAL(std::string("nonopt2"), nonopts[1]);
 }
 
+void OptionParserTest::testParse()
+{
+  Option option;
+  std::istringstream in("alpha=Hello\n"
+                        "UNKNOWN=x\n"
+                        "\n"
+                        "bravo=World");
+  _oparser->parse(option, in);
+  CPPUNIT_ASSERT_EQUAL
+    ((ptrdiff_t)2, std::distance(option.begin(), option.end()));
+  CPPUNIT_ASSERT_EQUAL(std::string("Hello"), option.get("alpha"));
+  CPPUNIT_ASSERT_EQUAL(std::string("World"), option.get("bravo"));
+}
+
 } // namespace aria2
